@@ -35,16 +35,16 @@ class DecoderSelfAttention(AttentionBase):
         attention_state: FloatTensor,
         token_index: LongTensor
     ) -> Tuple[FloatTensor, FloatTensor]:
-        keys = self.k_proj.forward(decoder_state).to(torch.float32)
-        values = self.v_proj.forward(decoder_state).to(torch.float32)
-        queries = self.q_proj.forward(decoder_state).to(torch.float32)
+        keys = self.k_proj.forward(decoder_state)
+        values = self.v_proj.forward(decoder_state)
+        queries = self.q_proj.forward(decoder_state)
         attn_mask = self.token_indices < token_index + 1
         attn_mask = attn_mask[None][[0] * decoder_state.shape[0]]
         attn_state_new = torch.cat([keys, values]).to(attention_state.dtype)
         attention_state[:, token_index] = attn_state_new
         batch_count = decoder_state.shape[0]
-        keys = attention_state[:batch_count].to(torch.float32)
-        values = attention_state[batch_count:].to(torch.float32)
+        keys = attention_state[:batch_count]
+        values = attention_state[batch_count:]
         decoder_state = super().forward(keys, values, queries, attn_mask)
         return decoder_state, attention_state
 
